﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;

namespace WnGValLst_CS
{
    public partial class Form1 : Form
    {
        UltraWinGridSample ds = new UltraWinGridSample(10);

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ug1.DataSource = ds;
        }

        private void ug1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            // Set UltraGrid Layout
            UltraWinGridSample.SetGridLayout(ug1);

            // Create and Add ValueList to UltraGrid
            this.ug1.DisplayLayout.ValueLists.Add("List1");

            // Add Items to ValueList, Index and DisplayText
            e.Layout.ValueLists["List1"].ValueListItems.Add(0, "Basic Support");
            e.Layout.ValueLists["List1"].ValueListItems.Add(1, "Enterprise Support");
            e.Layout.ValueLists["List1"].ValueListItems.Add(2, "General Support");
            e.Layout.ValueLists["List1"].ValueListItems.Add(3, "No Support");
            e.Layout.ValueLists["List1"].ValueListItems.Add(4, "Priority Support");
            e.Layout.ValueLists["List1"].ValueListItems.Add(5, "Standard Support");

            // Set ValueList Display Style to DisplayText
            e.Layout.ValueLists["List1"].DisplayStyle = ValueListDisplayStyle.DisplayText;

            // Add Column to UltraGrid and assign ValueList
            e.Layout.Bands[0].Columns.Add("Support");
            e.Layout.Bands[0].Columns["Support"].Header.Caption = "Support Contract";
            e.Layout.Bands[0].Columns["Support"].ValueList = e.Layout.ValueLists["List1"];
        }

        private void ug1_InitializeRow(object sender, Infragistics.Win.UltraWinGrid.InitializeRowEventArgs e)
        {
            // Set ValueListItem object to default value by index
            ValueListItem item = ug1.DisplayLayout.ValueLists["List1"].ValueListItems[2];

            // Default ValueList to Item 2 at Startup
            if (e.Row.Cells["Support"].Value == null)
            {
                e.Row.Cells["Support"].Value = item.DisplayText;
            }
        }
    }

    //Sample DataSet.
    public class UltraWinGridSample : DataSet
    {
        //Default contructor. Will default to customer count 50.
        public UltraWinGridSample()
        {
            this.ConfigureThis(50);
        }

        //Contsructor, sets buyer count.
        public UltraWinGridSample(uint custCnt)
        {
            this.ConfigureThis(custCnt);
        }

        //Configures the dataset.
        private void ConfigureThis(uint custCnt)
        {
            this.CreateSampleSchema();
            this.CreateSampleData(custCnt);
        }

        //Creates the schema for the sample data.
        private void CreateSampleSchema()
        {
            DataColumn[] keys = new DataColumn[1];

            this.Tables.Add("Customers");
            this.Tables[0].Columns.Add("AccountNumber", typeof(int));
            this.Tables[0].Columns.Add("FirstName", typeof(string));
            this.Tables[0].Columns.Add("LastName", typeof(string));
            this.Tables[0].Columns.Add("ContractDate", typeof(DateTime));

            keys[0] = this.Tables[0].Columns["AccountNumber"];
            this.Tables[0].PrimaryKey = keys;
            this.Tables[0].Columns["AccountNumber"].AutoIncrementSeed = 1024;
            this.Tables[0].Columns["AccountNumber"].AutoIncrementStep = 1;
            this.Tables[0].Columns["AccountNumber"].AutoIncrement = true;
        }

        //Populates the sample data.
        private void CreateSampleData(uint custCnt)
        {
            Random rndm = new Random();

            System.Collections.ArrayList accounts = new System.Collections.ArrayList();

            for (int i = 0; i < custCnt; i++)
            {
                int y = rndm.Next(DateTime.Now.AddYears(-20).Year, DateTime.Now.Year);
                int m = rndm.Next(1, 13);
                int d = rndm.Next(1, DateTime.DaysInMonth(y, m));
                int zip = rndm.Next(1, 99999);

                DateTime contDate = new DateTime(y, m, d);

                string fn = firstNames[rndm.Next(0, firstNames.Length)];
                string ln = lastNames[i % lastNames.Length];

                this.Tables["Customers"].Rows.Add(
                    new object[] { null, fn, ln, contDate });

                object[] row = this.Tables["Customers"].Rows[i].ItemArray;
                accounts.Add(Convert.ToInt32(row[0]));
            }
        }

        //Name arrays.
        private string[] firstNames = { "Mary", "Scott", "John", "Jim", "Keith", "Brian",
        "Harry", "Richard", "Robert", "Michael", "Matt", "George", "Don", "Vince",
        "Joe", "Jon", "Yale", "Nick", "Neil", "Bart", "William", "Bill", "Fry",
        "Jason", "Stephanie", "Bree", "Kim", "Kelly", "Lisa", "Joan", "Jennifer" };
        private string[] lastNames = { "Evans", "Harrison", "Smith", "Doe", "Johnson",
        "Griggs", "Harrelson", "Statham", "Williams", "Williamson", "Wells",
        "Cafaro", "Orris", "Dunn", "Taylor", "Lawrence", "Jennings", "Morris",
        "Lincoln", "Ford"};

        //Static helper method to set some basic layout settings.
        public static void SetGridLayout(Infragistics.Win.UltraWinGrid.UltraGrid ug)
        {
            //Scroll settings.
            ug.DisplayLayout.ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle.Immediate;
            ug.DisplayLayout.ScrollBounds = Infragistics.Win.UltraWinGrid.ScrollBounds.ScrollToFill;

            //Caption changes
            ug.DisplayLayout.Bands[0].Columns["AccountNumber"].Header.Caption = "Account No.";
            ug.DisplayLayout.Bands[0].Columns["FirstName"].Header.Caption = "First Name";
            ug.DisplayLayout.Bands[0].Columns["LastName"].Header.Caption = "Last Name";
            ug.DisplayLayout.Bands[0].Columns["ContractDate"].Header.Caption = "Contract Date";
        }
    }
}
